HNSW — hubness 0.21a1 documentation

# HNSW

class `hubness.neighbors.` `HNSW`(n_candidates: int = 5, metric: str = 'euclidean', method: str = 'hnsw', post_processing: int = 2, n_jobs: int = 1, verbose: int = 0)

  Bases: `hubness.neighbors.approximate_neighbors.ApproximateNearestNeighbor`

  Attributes Summary

  `valid_metrics` |

  Methods Summary

  `fit`(X[, y]) | Setup the HNSW index.
  `kneighbors`(X[, n_candidates, return_distance]) |

  Attributes Documentation

  `valid_metrics` = ['euclidean', 'l2', 'minkowski', 'cosine', 'cosinesimil']

  Methods Documentation

  `fit`(X, y=None) → hubness.neighbors.hnsw.HNSW

    Setup the HNSW index.

  `kneighbors`(X: numpy.ndarray, n_candidates: Optional[int] = None, return_distance: bool = True)